FetchStateRegistry class

Registry of fetch state managers by device ID.

Singleton pattern for managing fetch operations across multiple devices.

Inheritance

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createManager(String deviceId) FetchStateManager
Creates a new manager instance for the given device ID.
override
disposeAll() → void
Disposes all managers.
inherited
disposeManager(BluetoothDevice device) → void
Disposes and removes the manager for a device.
inherited
getFetchProgressStream(BluetoothDevice device) Stream<FetchProgress>
Gets the progress stream for a device (typed).
getManager(BluetoothDevice device) FetchStateManager
Gets or creates a state manager for the given device.
inherited
getProgressStream(BluetoothDevice device) Stream
Gets the progress stream for a device.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance FetchStateRegistry
no setter