OperationStateRegistry<TManager extends OperationStateManager> class abstract

Abstract registry for managing operation state managers by device ID.

Provides a single point of access for managing operations across multiple devices.

Implementers

Constructors

OperationStateRegistry()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createManager(String deviceId) → TManager
Creates a new manager instance for the given device ID.
disposeAll() → void
Disposes all managers.
disposeManager(BluetoothDevice device) → void
Disposes and removes the manager for a device.
getManager(BluetoothDevice device) → TManager
Gets or creates a state manager for the given device.
getProgressStream(BluetoothDevice device) Stream
Gets the progress stream for a device.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited