FetchMeasurementResult class abstract
- Available extensions
- Annotations
-
- @freezed
Constructors
- FetchMeasurementResult.failure(String message, [int? code])
-
constfactory
- FetchMeasurementResult.fromBytes(Uint8List data)
-
factory
- FetchMeasurementResult.success()
-
constfactory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
map<
TResult extends Object?> ({required TResult success(_Success value), required TResult failure(_Failure value)}) → TResult -
Available on FetchMeasurementResult, provided by the FetchMeasurementResultPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> ({TResult? success(_Success value)?, TResult? failure(_Failure value)?}) → TResult? -
Available on FetchMeasurementResult, provided by the FetchMeasurementResultPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> ({TResult success(_Success value)?, TResult failure(_Failure value)?, required TResult orElse()}) → TResult -
Available on FetchMeasurementResult, provided by the FetchMeasurementResultPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> ({TResult success()?, TResult failure(String message, int? code)?, required TResult orElse()}) → TResult -
Available on FetchMeasurementResult, provided by the FetchMeasurementResultPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> ({required TResult success(), required TResult failure(String message, int? code)}) → TResult -
Available on FetchMeasurementResult, provided by the FetchMeasurementResultPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> ({TResult? success()?, TResult? failure(String message, int? code)?}) → TResult? -
Available on FetchMeasurementResult, provided by the FetchMeasurementResultPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited