VtjAdvertisingDataPatterns extension

Adds pattern-matching-related methods to VtjAdvertisingData.

on

Methods

map<TResult extends Object?>(TResult $default(_VtjAdvertisingData value)) → TResult

Available on VtjAdvertisingData, provided by the VtjAdvertisingDataPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_VtjAdvertisingData value)?) → TResult?

Available on VtjAdvertisingData, provided by the VtjAdvertisingDataPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_VtjAdvertisingData value)?, {required TResult orElse()}) → TResult

Available on VtjAdvertisingData, provided by the VtjAdvertisingDataPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(int manufacturerId, int deviceTypeId, int batteryVoltage, String macAddress, DeviceState deviceState, bool hasValidServiceUuid, bool isConnectable, int flags, Map<int, List<int>> manufacturerData)?, {required TResult orElse()}) → TResult

Available on VtjAdvertisingData, provided by the VtjAdvertisingDataPatterns extension

A variant of when that fallback to an orElse callback.
when<TResult extends Object?>(TResult $default(int manufacturerId, int deviceTypeId, int batteryVoltage, String macAddress, DeviceState deviceState, bool hasValidServiceUuid, bool isConnectable, int flags, Map<int, List<int>> manufacturerData)) → TResult

Available on VtjAdvertisingData, provided by the VtjAdvertisingDataPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(int manufacturerId, int deviceTypeId, int batteryVoltage, String macAddress, DeviceState deviceState, bool hasValidServiceUuid, bool isConnectable, int flags, Map<int, List<int>> manufacturerData)?) → TResult?

Available on VtjAdvertisingData, provided by the VtjAdvertisingDataPatterns extension

A variant of when that fallback to returning null