BluePlusVtjDatasource class
- Implemented types
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
authenticateDevice(
BluetoothDevice device, String deviceKey) → Future< VtjCommandResult< bool> > -
override
-
connectToDevice(
BluetoothDevice device) → Future< void> -
override
-
deleteMeasurement(
BluetoothDevice device) → Future< VtjCommandResult< DeleteMeasurementResult> > -
override
-
disconnectFromDevice(
BluetoothDevice device) → Future< void> -
override
-
enterDfuBootloader(
BluetoothDevice device) → Future< VtjCommandResult< EnterDfuBootloaderResult> > -
Reboot the device into DFU Bootloader mode for firmware upgrade.
Note: Device will disconnect after this command.
See BLE Interface Specification Section 7.10
override
-
fetchMeasurement(
BluetoothDevice device, MeasurementConfig config, {int startIndex = 0}) → Future< VtjCommandResult< FetchMeasurementResult> > -
Start download of last completed measurement.
Data will be sent via the RPC Download Characteristic.
See BLE Interface Specification Section 7.6
override
-
fetchProgressStream(
BluetoothDevice device) → Stream< FetchProgress> -
Stream of fetch progress events for the given device.
override
-
getDeviceState(
BluetoothDevice device) → Future< VtjCommandResult< GetDeviceStateResult> > -
override
-
getScanResults(
) → Stream< List< ScanResult> > -
override
-
getVersion(
BluetoothDevice device) → Future< VtjCommandResult< GetVersionResult> > -
override
-
identifyBlink(
BluetoothDevice device) → Future< VtjCommandResult< IdentifyBlinkResult> > -
Perform an identify blink pattern on the device LED.
See BLE Interface Specification Section 7.9
override
-
measurementProgressStream(
BluetoothDevice device) → Stream< MeasurementProgress> -
Stream of measurement progress events for the given device.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
performAccelSelfTest(
BluetoothDevice device) → Future< VtjCommandResult< AccelSelfTestResult> > -
override
-
performBattSelfTest(
BluetoothDevice device) → Future< VtjCommandResult< BattSelfTestResult> > -
override
-
requestPermissions(
) → Future< bool> -
resetFetchState(
BluetoothDevice device) → void -
Resets the fetch state for a device, canceling any in-progress fetch.
override
-
resetMeasurementState(
BluetoothDevice device) → void -
Resets the measurement state for a device, canceling any in-progress measurement tracking.
override
-
startMeasurement(
BluetoothDevice device, MeasurementConfig config) → Future< VtjCommandResult< StartMeasurementResult> > -
Start an accelerometer measurement with the given configuration.
See BLE Interface Specification Section 7.3
override
-
startScan(
{int? scanningDuration = defaultScanningDuration}) → Future< void> -
override
-
stopFetchMeasurement(
BluetoothDevice device) → Future< VtjCommandResult< StopFetchMeasurementResult> > -
Stop sending measurement data (started with fetchMeasurement).
See BLE Interface Specification Section 7.13
override
-
stopMeasurement(
BluetoothDevice device) → Future< VtjCommandResult< StopMeasurementResult> > -
Prematurely stop an accelerometer measurement.
See BLE Interface Specification Section 7.4
override
-
stopScan(
) → Future< void> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- rpcDownloadCharUuid → const String