VtjCommandExecutor class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
dispose(
) → void -
executeCommand<
T> (VtjCommand< T> command) → Future<VtjCommandResult< T> > -
initializeCharacteristics(
BluetoothDevice device) → Future< VtjCommandResult< void> > -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- rpcCallCharUuid → const String
- rpcReplyCharUuid → const String
- serviceUuid → const String