VtjDevicesDatasource class abstract
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
authenticateDevice(
BluetoothDevice device, String deviceKey) → Future< VtjCommandResult< bool> > -
connectToDevice(
BluetoothDevice device) → Future< void> -
deleteMeasurement(
BluetoothDevice device) → Future< VtjCommandResult< DeleteMeasurementResult> > -
disconnectFromDevice(
BluetoothDevice device) → Future< void> -
enterDfuBootloader(
BluetoothDevice device) → Future< VtjCommandResult< EnterDfuBootloaderResult> > - Reboot the device into DFU Bootloader mode for firmware upgrade. Note: Device will disconnect after this command. See BLE Interface Specification Section 7.10
-
fetchMeasurement(
BluetoothDevice device, MeasurementConfig config, {int startIndex = 0}) → Future< VtjCommandResult< FetchMeasurementResult> > - Start download of last completed measurement. Data will be sent via the RPC Download Characteristic. See BLE Interface Specification Section 7.6
-
fetchProgressStream(
BluetoothDevice device) → Stream< FetchProgress> - Stream of fetch progress events for the given device.
-
getDeviceState(
BluetoothDevice device) → Future< VtjCommandResult< GetDeviceStateResult> > -
getScanResults(
) → Stream< List< ScanResult> > -
getVersion(
BluetoothDevice device) → Future< VtjCommandResult< GetVersionResult> > -
identifyBlink(
BluetoothDevice device) → Future< VtjCommandResult< IdentifyBlinkResult> > - Perform an identify blink pattern on the device LED. See BLE Interface Specification Section 7.9
-
measurementProgressStream(
BluetoothDevice device) → Stream< MeasurementProgress> - Stream of measurement progress events for the given device.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
performAccelSelfTest(
BluetoothDevice device) → Future< VtjCommandResult< AccelSelfTestResult> > -
performBattSelfTest(
BluetoothDevice device) → Future< VtjCommandResult< BattSelfTestResult> > -
resetFetchState(
BluetoothDevice device) → void - Resets the fetch state for a device, canceling any in-progress fetch.
-
resetMeasurementState(
BluetoothDevice device) → void - Resets the measurement state for a device, canceling any in-progress measurement tracking.
-
startMeasurement(
BluetoothDevice device, MeasurementConfig config) → Future< VtjCommandResult< StartMeasurementResult> > - Start an accelerometer measurement with the given configuration. See BLE Interface Specification Section 7.3
-
startScan(
{int? scanningDuration = 15}) → Future< void> -
stopFetchMeasurement(
BluetoothDevice device) → Future< VtjCommandResult< StopFetchMeasurementResult> > - Stop sending measurement data (started with fetchMeasurement). See BLE Interface Specification Section 7.13
-
stopMeasurement(
BluetoothDevice device) → Future< VtjCommandResult< StopMeasurementResult> > - Prematurely stop an accelerometer measurement. See BLE Interface Specification Section 7.4
-
stopScan(
) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited