VtjCommandResult<T> class
- Available extensions
- Annotations
-
- @freezed
Constructors
- VtjCommandResult.failure(String error, int? statusCode)
-
constfactory
- VtjCommandResult.success(T data)
-
constfactory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → T
-
no setter
Methods
-
map<
TResult extends Object?> ({required TResult success(_Success< T> value), required TResult failure(_Failure<T> value)}) → TResult -
Available on VtjCommandResult<
AT> , provided by the VtjCommandResultPatterns extensionswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> ({TResult? success(_Success< T> value)?, TResult? failure(_Failure<T> value)?}) → TResult? -
Available on VtjCommandResult<
A variant ofT> , provided by the VtjCommandResultPatterns extensionmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> ({TResult success(_Success< T> value)?, TResult failure(_Failure<T> value)?, required TResult orElse()}) → TResult -
Available on VtjCommandResult<
A variant ofT> , provided by the VtjCommandResultPatterns extensionmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> ({TResult success(T data)?, TResult failure(String error, int? statusCode)?, required TResult orElse()}) → TResult -
Available on VtjCommandResult<
A variant ofT> , provided by the VtjCommandResultPatterns extensionwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> ({required TResult success(T data), required TResult failure(String error, int? statusCode)}) → TResult -
Available on VtjCommandResult<
AT> , provided by the VtjCommandResultPatterns extensionswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> ({TResult? success(T data)?, TResult? failure(String error, int? statusCode)?}) → TResult? -
Available on VtjCommandResult<
A variant ofT> , provided by the VtjCommandResultPatterns extensionwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited